@@ -544,7 +544,8 @@ def deploycode(branch, nltkLoad="False", doCollectStatic="True", djangoAdmin="Tr
         collect_static()
     else:
         if (not yarn in TRUTH_VALUES) and (djangoAdmin in TRUTH_VALUES):
-            sudo('cp -r ' + '/usr/local/lib/python2.7/dist-packages' +
+ #           sudo('cp -r ' + '/usr/local/lib/python2.7/dist-packages' +
+             sudo('cp -r ' + '/usr/local/opt/python/lib/python2.7/site-packages' +
                  '/django/contrib/admin/static/admin /data/deploy/pending/static/')
 
     if not immutable in TRUTH_VALUES:
@@ -571,7 +572,8 @@ def deployParallel(nltkLoad="False", doCollectStatic="True", djangoAdmin="True",
         collect_static()
     else:
         if (not yarn in TRUTH_VALUES) and (djangoAdmin in TRUTH_VALUES):
-            sudo('cp -r ' + '/usr/local/lib/python2.7/dist-packages' +
+#            sudo('cp -r ' + '/usr/local/lib/python2.7/dist-packages' +
+             sudo('cp -r ' + '/usr/local/opt/python/lib/python2.7/site-packages' +
                  '/django/contrib/admin/static/admin /data/deploy/pending/static/')
 
     if not immutable in TRUTH_VALUES:
@@ -654,12 +656,12 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     cmd = "mkdir -p " + UPLOAD_CODE_PATH + "/" + APP_UTILS_DIR
     run(cmd)
     with cd('%s' % UPLOAD_CODE_PATH):
-        put('%s.tar.gz' % TAR_NAME, '%s.tar.gz' % TAR_NAME, use_sudo=True)
+        put('%s.tar.gz' % TAR_NAME, '%s.tar.gz' % TAR_NAME)
         run('tar zxf %s.tar.gz -C %s' % (TAR_NAME, APP_UTILS_DIR))
 
     # run the "instanceType"-command.sh in the appropriate branch
-    cmdToRun = "/home/ubuntu/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
-    sudo(cmdToRun)
+    cmdToRun = "sudo --preserve-env=HOME /home/ubuntu/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
+    run(cmdToRun)
 
     # run deployenv on the instance to get the new values into /etc/enviornmnet
     run("deployenv.sh --type instance -a " + appname + " -e " + ENVIRONMENT)
